@@ -244,7 +244,7 @@ class BipartiteLongCollapsed(bpd.BipartiteLongBase):
                     del long_frame.col_collapse_dict[col]
                     del long_frame.col_long_es_dict[col]
                     if col in long_frame.columns_contig.keys():
-                        # If column is contiguous
+                        # If column is categorical
                         del long_frame.columns_contig[col]
                         if long_frame.id_reference_dict:
                             # If linking contiguous ids to original ids
@@ -267,6 +267,9 @@ class BipartiteLongCollapsed(bpd.BipartiteLongBase):
         Returns:
             (NumPy Array): spell ids
         '''
+        if not is_sorted:
+            raise NotImplementedError('._get_spell_ids() requires `is_sorted` == True, but it is set to False.')
+
         if self.no_returns:
             # If no returns, then each observation is guaranteed to be a new spell
             self.log('preparing to compute spell ids', level='info')
